Class: TagLib::MP4::File
Overview
The file class for '.m4a' files.
Class Method Summary collapse
-
.open(filename, read_properties = true) {|file| ... } ⇒ Object
Creates a new file and passes it to the provided block, closing the file automatically at the end of the block.
Note that after the block is done, the file is closed and all memory is released for objects read from the file (basically everything from the
TagLibnamespace).Using
openis preferable to usingnewand then manuallyclose.
Instance Method Summary collapse
- #audio_properties ⇒ TagLib::MP4::Properties
-
#initialize(filename, read_properties = true) ⇒ TagLib::MP4::File
constructor
Load an M4A file.
-
#mp4_tag? ⇒ Boolean
file has a Metadata Item List (ilst) atom.
-
#tag ⇒ TagLib::MP4::Tag?
Returns the MP4 tag in the file.
Methods inherited from File
Constructor Details
#initialize(filename, read_properties = true) ⇒ TagLib::MP4::File
Load an M4A file.
72 73 |
# File 'docs/taglib/mp4.rb', line 72 def initialize(filename, read_properties=true) end |
Class Method Details
.open(filename, read_properties = true) {|file| ... } ⇒ Object
Creates a new file and passes it to the provided block, closing the file automatically at the end of the block.
Note that after the block is done, the file is closed and
all memory is released for objects read from the file
(basically everything from the TagLib namespace).
Using open is preferable to using new and then
manually close.
63 64 |
# File 'docs/taglib/mp4.rb', line 63 def self.open(filename, read_properties=true) end |
Instance Method Details
#audio_properties ⇒ TagLib::MP4::Properties
83 84 |
# File 'docs/taglib/mp4.rb', line 83 def audio_properties end |
#mp4_tag? ⇒ Boolean
file has a Metadata Item List (ilst) atom.
90 91 |
# File 'docs/taglib/mp4.rb', line 90 def mp4_tag? end |
#tag ⇒ TagLib::MP4::Tag?
Returns the MP4 tag in the file
79 80 |
# File 'docs/taglib/mp4.rb', line 79 def tag end |