Class: TagLib::MP4::Tag
Instance Attribute Summary
Attributes inherited from Tag
#album, #artist, #comment, #genre, #title, #track, #year
Instance Method Summary collapse
-
#[](key) ⇒ TagLib::MP4::Item
The Item associated to
key(will be invalid inkeydoes not exists). -
#[]=(key, value) ⇒ nil
Associate the
valueItem tokey, overwriting any previous value. -
#contains(key) ⇒ Object
True if the tag has an entry for
key, false otherwise. -
#item_map ⇒ TagLib::MP4::ItemMap
The map containing all the items in the tag.
-
#remove_item(key) ⇒ nil
Remove the [TagLib::MP4::Item] associated to
key.
Methods inherited from Tag
Instance Method Details
#[](key) ⇒ TagLib::MP4::Item
Returns The Item associated to key (will be invalid in key does not exists).
104 105 |
# File 'docs/taglib/mp4.rb', line 104 def [](key) end |
#[]=(key, value) ⇒ nil
Associate the value Item to key, overwriting any previous value.
113 114 |
# File 'docs/taglib/mp4.rb', line 113 def []=(key, value) end |
#contains(key) ⇒ Object
Returns True if the tag has an entry for key, false otherwise.
126 127 |
# File 'docs/taglib/mp4.rb', line 126 def contains(key) end |
#item_map ⇒ TagLib::MP4::ItemMap
Returns The map containing all the items in the tag.
98 99 |
# File 'docs/taglib/mp4.rb', line 98 def item_map end |
#remove_item(key) ⇒ nil
Remove the [TagLib::MP4::Item] associated to key.
120 121 |
# File 'docs/taglib/mp4.rb', line 120 def remove_item(key) end |