Method: TagLib::MPEG::File#strip

Defined in:
docs/taglib/mpeg.rb

#strip(tags = TagLib::MPEG::File::AllTags) ⇒ Boolean

Strip the specified tags from the file. Note that this directly updates the file, a call to save afterwards is not necessary (closing the file is necessary as always, though).

Parameters:

  • tags (Integer) (defaults to: TagLib::MPEG::File::AllTags)

    The tag types to strip (see constants), e.g. ID3v2. To specify more than one tag type, or them together using |, e.g. TagLib::MPEG::File::ID3v1 | TagLib::MPEG::File::ID3v2.

Returns:

  • (Boolean)

    whether stripping was successful



96
97
# File 'docs/taglib/mpeg.rb', line 96

def strip(tags=TagLib::MPEG::File::AllTags)
end