Class: TagLib::FileRef
- Inherits:
-
Object
- Object
- TagLib::FileRef
- Defined in:
- docs/taglib/base.rb
Overview
This class allows to read basic tagging and audio properties from files, without having to know what the file type is. Thus, it works for all tagging formats that taglib supports, but only provides a minimal API.
Should you need more, use the file type specific classes, see subclasses of File.
Class Method Summary collapse
-
.open(filename, read_audio_properties = true, audio_properties_style = TagLib::AudioProperties::Average) {|file| ... } ⇒ Object
Creates a new file and passes it to the provided block, closing the file automatically at the end of the block.
Instance Method Summary collapse
-
#audio_properties ⇒ TagLib::AudioProperties
The audio properties.
-
#close ⇒ void
Closes the file and releases all objects that were read from the file.
-
#initialize(filename, read_audio_properties = true, audio_properties_style = TagLib::AudioProperties::Average) ⇒ FileRef
constructor
Create a FileRef from a file name.
-
#null? ⇒ Boolean
If the file is null (i.e. it could not be read).
-
#save ⇒ Boolean
Saves the file.
-
#tag ⇒ TagLib::Tag
The tag.
Constructor Details
#initialize(filename, read_audio_properties = true, audio_properties_style = TagLib::AudioProperties::Average) ⇒ FileRef
Create a FileRef from a file name.
85 86 87 |
# File 'docs/taglib/base.rb', line 85 def initialize(filename, read_audio_properties=true, audio_properties_style=TagLib::AudioProperties::Average) end |
Class Method Details
.open(filename, read_audio_properties = true, audio_properties_style = TagLib::AudioProperties::Average) {|file| ... } ⇒ Object
Creates a new file and passes it to the provided block, closing the file automatically at the end of the block.
Note that after the block is done, the file is closed and
all memory is released for objects read from the file
(basically everything from the TagLib namespace).
Using open is preferable to using new and then
manually close.
73 74 75 |
# File 'docs/taglib/base.rb', line 73 def self.open(filename, read_audio_properties=true, audio_properties_style=TagLib::AudioProperties::Average) end |
Instance Method Details
#audio_properties ⇒ TagLib::AudioProperties
Returns the audio properties.
90 91 |
# File 'docs/taglib/base.rb', line 90 def audio_properties end |
#close ⇒ void
This method returns an undefined value.
Closes the file and releases all objects that were read from the file.
113 114 |
# File 'docs/taglib/base.rb', line 113 def close end |
#null? ⇒ Boolean
Returns if the file is null (i.e. it could not be read).
94 95 |
# File 'docs/taglib/base.rb', line 94 def null? end |
#save ⇒ Boolean
Saves the file
100 101 |
# File 'docs/taglib/base.rb', line 100 def save end |