Method: TagLib::FileRef.open
- Defined in:
- docs/taglib/base.rb
.open(filename, read_audio_properties = true, audio_properties_style = TagLib::AudioProperties::Average) {|file| ... } ⇒ Object
Creates a new file and passes it to the provided block, closing the file automatically at the end of the block.
Note that after the block is done, the file is closed and
all memory is released for objects read from the file
(basically everything from the TagLib namespace).
Using open is preferable to using new and then
manually close.
111 112 113 |
# File 'docs/taglib/base.rb', line 111 def self.open(filename, read_audio_properties=true, audio_properties_style=TagLib::AudioProperties::Average) end |