Method: TagLib::MP4::File.open
- Defined in:
- docs/taglib/mp4.rb
.open(filename, read_properties = true) {|file| ... } ⇒ Object
Creates a new file and passes it to the provided block, closing the file automatically at the end of the block.
Note that after the block is done, the file is closed and
all memory is released for objects read from the file
(basically everything from the TagLib namespace).
Using open is preferable to using new and then
manually close.
63 64 |
# File 'docs/taglib/mp4.rb', line 63 def self.open(filename, read_properties=true) end |